@@ -8,14 +8,14 @@ package MBX::FLTK;
     use ExtUtils::CBuilder qw[];
     use File::Spec::Functions qw[catdir rel2abs abs2rel canonpath];
     use File::Find qw[find];
-    use File::Path 2.07 qw[make_path];
+    use File::Path qw[make_path];
     use base 'Module::Build';
     {
-        sub cxxflags { return '' }
 
         sub ACTION_code {
             require Alien::FLTK;    # Should be installed by now
             my ($self, $args) = @_;
+            my $AF = Alien::FLTK->new();
             my (@xs, @rc, @obj);
             find(sub { push @xs, $File::Find::name if m[.+\.xs$]; }, 'xs');
             find(sub { push @rc, $File::Find::name if !m[.+\.o$]; }, 'xs/rc');
@@ -47,9 +47,10 @@ package MBX::FLTK;
                 }
                 push @obj,
                     $self->cbuilder->compile(
-                              source => $cpp,
-                              extra_compiler_flags =>
-                                  [Alien::FLTK->cxxflags(), $self->cxxflags()]
+                                       'C++'        => 1,
+                                       source       => $cpp,
+                                       include_dirs => [$AF->include_dirs()],
+                                       extra_compiler_flags => $AF->cxxflags()
                     );
             }
             make_path(catdir(qw[blib arch auto FLTK]),
@@ -63,13 +64,13 @@ package MBX::FLTK;
                 )
             {   my ($dll, @cleanup)
                     = $self->cbuilder->link(
-                    objects => \@obj,
-                    lib_file =>
-                        catdir(qw[blib arch auto FLTK],
-                               'FLTK.' . $Config{'so'}
-                        ),
-                    module_name        => 'FLTK',
-                    extra_linker_flags => Alien::FLTK->ldflags(qw[gl images]),
+                            objects => \@obj,
+                            lib_file =>
+                                catdir(qw[blib arch auto FLTK],
+                                       'FLTK.' . $Config{'so'}
+                                ),
+                            module_name        => 'FLTK',
+                            extra_linker_flags => $AF->ldflags(qw[gl images]),
                     );
                 @cleanup = map { s["][]g; rel2abs($_); } @cleanup;
                 $self->add_to_cleanup(@cleanup);
@@ -112,7 +113,12 @@ package MBX::FLTK;
 
         sub ACTION_docs {
             my $self = shift;
-            $self->depends_on('apidoc');
+            if ($self->notes('skip_apidoc')) {
+                $self->notes('skip_apidoc' => 0);
+            }
+            else {
+                $self->depends_on('apidoc');
+            }
             return $self->SUPER::ACTION_docs(@_);
         }
         use File::Path qw[make_path];
@@ -311,7 +317,7 @@ package MBX::FLTK;
             #   write documentation in here
             #   mention defaults/types/import tags
             my ($return, $call, @args) = ('', '', ());
-            my %types = ('AV *' => '@', 'CV *' => '\&');
+            my %types = ('AV *' => '@', 'CV *' => '\&', 'HV *' => "\%");
             for my $arg (@{$use->{'args'}}) {
                 my ($type, $name, $default)
                     = ($arg
@@ -331,8 +337,6 @@ package MBX::FLTK;
                         ) . $name;
                 }
             }
-
-            #
             if ($use->{'return'}) {
                 my ($type, $name, $default)
                     = ($use->{'return'}
@@ -355,10 +359,10 @@ package MBX::FLTK;
                 : sub {
                 my $p = shift;
                 $p =~ s|^.*:|\$|g;
-                return lc "$p->";
+                return lc($p) . '-E<gt>';
                 }
                 ->($package);
-            my $usage = sprintf '%s%s%s(%s%s )', $return, $call, $sub,
+            my $usage = sprintf '%s%s%s(%s%s );', $return, $call, $sub,
                 (@args ? ' ' : ''), (join ', ', @args);
             return $usage;
         }
@@ -368,15 +372,15 @@ package MBX::FLTK;
 
 =pod
 
-=for $Rev: 4240aaf $
+=for $Rev: c9b696e $
 
-=for $Revision: 4240aafb0936e2b2d3ff7065e09bfb641242b026 $
+=for $Revision: c9b696ef5a2b09285cba3bbf0fb3f91cd4692b24 $
 
-=for $Date: 2009-09-24 21:42:29Z (Thu, 24 Sep 2009) $ | Last $Modified: 10 days ago $
+=for $Date: 2009-11-05 18:41:28Z (Thu, 05 Nov 2009) $ | Last $Modified: 3 days ago $
 
-=for $URL: http://github.com/sanko/fltk-perl/raw/4240aafb0936e2b2d3ff7065e09bfb641242b026/inc/MBX/FLTK.pm $
+=for $URL: http://github.com/sanko/fltk-perl/raw/master/inc/MBX/FLTK.pm $
 
-=for $ID: FLTK.pm 4240aaf 2009-09-24 21:42:29Z sanko@cpan.org $
+=for $ID: FLTK.pm c9b696e 2009-11-05 18:41:28Z sanko@cpan.org $
 
 =for author Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
 
